@@ -75,9 +75,12 @@ class Stream_Enhancer:
     # -- subtraction of mask
     frame_bg = None
     sub_bg = False
+    frame_fg = None
+    mix_fg = False
 
     # background path
     BGFILE = os.path.expanduser('~/.config/flashcam/background.jpg')
+    FGFILE = os.path.expanduser('~/.config/flashcam/foreground.jpg')
 
 
     def RC_COLOR(self,row,col):
@@ -371,6 +374,13 @@ class Stream_Enhancer:
         # frame_bg2 = cv2.imencode('.jpg', frame_bg)[1].tobytes()
         # save_bg = False
 
+    def save_foreground(self):
+        cv2.imwrite( self.FGFILE , self.frame ) # nicely saved
+        self.frame_fg = self.frame.copy() # else artifacts remain
+        # frame_bg = self.frame.copy()
+        # frame_bg2 = cv2.imencode('.jpg', frame_bg)[1].tobytes()
+        # save_bg = False
+
     def subtract(self):
         if self.frame_bg is None:
             if os.path.exists( self.BGFILE ):
@@ -386,6 +396,24 @@ class Stream_Enhancer:
 
 
 
+    def mix(self):
+        if self.frame_fg is None:
+            if os.path.exists( self.FGFILE ):
+                self.frame_fg = cv2.imread( self.FGFILE )
+                print("OLD FOREGROUND IMAGE FOUND", self.frame_fg.shape)
+            else:
+                return
+        frame1 = 0.5*self.frame + 0.5*self.frame_fg
+        #*imgs[ random.randint(0,len(imgs)-1) ]
+
+        #frame1 = cv2.subtract(self.frame , self.frame_fg ) #, mask = frame_mask
+        # frame 1 is difference...
+        # frame1[:22,:]  = self.frame [:22,:]
+        # frame1[-22:,:] = self.frame [-22:,:]
+        self.frame = frame1
+
+
+
     def reset_camera_start(self):
         self.camera_start = dt.datetime.now()
 
